"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.monitoring.v3.unit_format_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class LabelValuesParameter(google.protobuf.message.Message):
    """Label values parameter."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    SELECTORS_FIELD_NUMBER: builtins.int
    LABEL_KEY_FIELD_NUMBER: builtins.int
    MULTISELECTABLE_FIELD_NUMBER: builtins.int
    DEFAULT_VALUES_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Required. Folder ID."""
    selectors: builtins.str
    """Required. Selectors to select metric label values."""
    label_key: builtins.str
    """Required. Label key to list label values."""
    multiselectable: builtins.bool
    """Specifies the multiselectable values of parameter."""
    @property
    def default_values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Default values."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        selectors: builtins.str = ...,
        label_key: builtins.str = ...,
        multiselectable: builtins.bool = ...,
        default_values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["container", b"container", "folder_id", b"folder_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["container", b"container", "default_values", b"default_values", "folder_id", b"folder_id", "label_key", b"label_key", "multiselectable", b"multiselectable", "selectors", b"selectors"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["container", b"container"]) -> typing.Literal["folder_id"] | None: ...

global___LabelValuesParameter = LabelValuesParameter

@typing.final
class CustomParameter(google.protobuf.message.Message):
    """Custom parameter."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUES_FIELD_NUMBER: builtins.int
    MULTISELECTABLE_FIELD_NUMBER: builtins.int
    DEFAULT_VALUES_FIELD_NUMBER: builtins.int
    multiselectable: builtins.bool
    """Specifies the multiselectable values of parameter."""
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Required. List of parameter values."""

    @property
    def default_values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Default values."""

    def __init__(
        self,
        *,
        values: collections.abc.Iterable[builtins.str] | None = ...,
        multiselectable: builtins.bool = ...,
        default_values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["default_values", b"default_values", "multiselectable", b"multiselectable", "values", b"values"]) -> None: ...

global___CustomParameter = CustomParameter

@typing.final
class TextParameter(google.protobuf.message.Message):
    """Text parameter."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    default_value: builtins.str
    """Default value."""
    def __init__(
        self,
        *,
        default_value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["default_value", b"default_value"]) -> None: ...

global___TextParameter = TextParameter

@typing.final
class DoubleParameter(google.protobuf.message.Message):
    """Double parameter."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    UNIT_FORMAT_FIELD_NUMBER: builtins.int
    default_value: builtins.float
    """Default value."""
    unit_format: yandex.cloud.monitoring.v3.unit_format_pb2.UnitFormat.ValueType
    """Parameter unit."""
    def __init__(
        self,
        *,
        default_value: builtins.float = ...,
        unit_format: yandex.cloud.monitoring.v3.unit_format_pb2.UnitFormat.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["default_value", b"default_value", "unit_format", b"unit_format"]) -> None: ...

global___DoubleParameter = DoubleParameter

@typing.final
class IntegerParameter(google.protobuf.message.Message):
    """Integer parameter."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    UNIT_FORMAT_FIELD_NUMBER: builtins.int
    default_value: builtins.int
    """Default value."""
    unit_format: yandex.cloud.monitoring.v3.unit_format_pb2.UnitFormat.ValueType
    """Parameter unit."""
    def __init__(
        self,
        *,
        default_value: builtins.int = ...,
        unit_format: yandex.cloud.monitoring.v3.unit_format_pb2.UnitFormat.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["default_value", b"default_value", "unit_format", b"unit_format"]) -> None: ...

global___IntegerParameter = IntegerParameter

@typing.final
class TextValuesParameter(google.protobuf.message.Message):
    """Text multiple values parameter."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_VALUES_FIELD_NUMBER: builtins.int
    @property
    def default_values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Default value."""

    def __init__(
        self,
        *,
        default_values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["default_values", b"default_values"]) -> None: ...

global___TextValuesParameter = TextValuesParameter

@typing.final
class Parameter(google.protobuf.message.Message):
    """Parameter."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    LABEL_VALUES_FIELD_NUMBER: builtins.int
    CUSTOM_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    INTEGER_PARAMETER_FIELD_NUMBER: builtins.int
    DOUBLE_PARAMETER_FIELD_NUMBER: builtins.int
    TEXT_VALUES_FIELD_NUMBER: builtins.int
    HIDDEN_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Parameter identifier."""
    title: builtins.str
    """UI-visible title of the parameter."""
    hidden: builtins.bool
    """UI-visibility."""
    description: builtins.str
    """Parameter description."""
    @property
    def label_values(self) -> global___LabelValuesParameter:
        """Label values parameter."""

    @property
    def custom(self) -> global___CustomParameter:
        """Custom parameter."""

    @property
    def text(self) -> global___TextParameter:
        """Text parameter."""

    @property
    def integer_parameter(self) -> global___IntegerParameter:
        """Integer parameter."""

    @property
    def double_parameter(self) -> global___DoubleParameter:
        """Double parameter."""

    @property
    def text_values(self) -> global___TextValuesParameter:
        """Integer parameter."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        title: builtins.str = ...,
        label_values: global___LabelValuesParameter | None = ...,
        custom: global___CustomParameter | None = ...,
        text: global___TextParameter | None = ...,
        integer_parameter: global___IntegerParameter | None = ...,
        double_parameter: global___DoubleParameter | None = ...,
        text_values: global___TextValuesParameter | None = ...,
        hidden: builtins.bool = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["custom", b"custom", "data", b"data", "double_parameter", b"double_parameter", "integer_parameter", b"integer_parameter", "label_values", b"label_values", "text", b"text", "text_values", b"text_values"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["custom", b"custom", "data", b"data", "description", b"description", "double_parameter", b"double_parameter", "hidden", b"hidden", "integer_parameter", b"integer_parameter", "label_values", b"label_values", "name", b"name", "text", b"text", "text_values", b"text_values", "title", b"title"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["data", b"data"]) -> typing.Literal["label_values", "custom", "text", "integer_parameter", "double_parameter", "text_values"] | None: ...

global___Parameter = Parameter

@typing.final
class Parametrization(google.protobuf.message.Message):
    """Parametrization."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMETERS_FIELD_NUMBER: builtins.int
    SELECTORS_FIELD_NUMBER: builtins.int
    selectors: builtins.str
    """Predefined selectors."""
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Parameter]:
        """Parameters."""

    def __init__(
        self,
        *,
        parameters: collections.abc.Iterable[global___Parameter] | None = ...,
        selectors: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["parameters", b"parameters", "selectors", b"selectors"]) -> None: ...

global___Parametrization = Parametrization



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CompletionOptions(google.protobuf.message.Message):
    """Defines the options for completion generation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_FIELD_NUMBER: builtins.int
    TEMPERATURE_FIELD_NUMBER: builtins.int
    MAX_TOKENS_FIELD_NUMBER: builtins.int
    stream: builtins.bool
    """Enables streaming of partially generated text."""
    @property
    def temperature(self) -> google.protobuf.wrappers_pb2.DoubleValue:
        """Affects creativity and randomness of responses. Should be a double number between 0 (inclusive) and 1 (inclusive).
        Lower values produce more straightforward responses while higher values lead to increased creativity and randomness.
        Default temperature: 0.3
        """

    @property
    def max_tokens(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The limit on the number of tokens used for single completion generation.
        Must be greater than zero. This maximum allowed parameter value may depend on the model being used.
        """

    def __init__(
        self,
        *,
        stream: builtins.bool = ...,
        temperature: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        max_tokens: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["max_tokens", b"max_tokens", "temperature", b"temperature"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["max_tokens", b"max_tokens", "stream", b"stream", "temperature", b"temperature"]) -> None: ...

global___CompletionOptions = CompletionOptions

@typing.final
class Message(google.protobuf.message.Message):
    """A message object representing a wrapper over the inputs and outputs of the completion model."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLE_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    TOOL_CALL_LIST_FIELD_NUMBER: builtins.int
    TOOL_RESULT_LIST_FIELD_NUMBER: builtins.int
    role: builtins.str
    """The ID of the message sender. Supported roles:
    * `system`: Special role used to define the behaviour of the completion model.
    * `assistant`: A role used by the model to generate responses.
    * `user`: A role used by the user to describe requests to the model.
    """
    text: builtins.str
    """Textual content of the message."""
    @property
    def tool_call_list(self) -> global___ToolCallList:
        """List of tool calls made by the model as part of the response generation."""

    @property
    def tool_result_list(self) -> global___ToolResultList:
        """List of tool results returned from external tools that were invoked by the model."""

    def __init__(
        self,
        *,
        role: builtins.str = ...,
        text: builtins.str = ...,
        tool_call_list: global___ToolCallList | None = ...,
        tool_result_list: global___ToolResultList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["Content", b"Content", "text", b"text", "tool_call_list", b"tool_call_list", "tool_result_list", b"tool_result_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["Content", b"Content", "role", b"role", "text", b"text", "tool_call_list", b"tool_call_list", "tool_result_list", b"tool_result_list"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["Content", b"Content"]) -> typing.Literal["text", "tool_call_list", "tool_result_list"] | None: ...

global___Message = Message

@typing.final
class ContentUsage(google.protobuf.message.Message):
    """An object representing the number of content [tokens](/docs/foundation-models/concepts/yandexgpt/tokens) used by the completion model."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INPUT_TEXT_TOKENS_FIELD_NUMBER: builtins.int
    COMPLETION_TOKENS_FIELD_NUMBER: builtins.int
    TOTAL_TOKENS_FIELD_NUMBER: builtins.int
    input_text_tokens: builtins.int
    """The number of tokens in the textual part of the model input."""
    completion_tokens: builtins.int
    """The number of tokens in the generated completion."""
    total_tokens: builtins.int
    """The total number of tokens, including all input tokens and all generated tokens."""
    def __init__(
        self,
        *,
        input_text_tokens: builtins.int = ...,
        completion_tokens: builtins.int = ...,
        total_tokens: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["completion_tokens", b"completion_tokens", "input_text_tokens", b"input_text_tokens", "total_tokens", b"total_tokens"]) -> None: ...

global___ContentUsage = ContentUsage

@typing.final
class Alternative(google.protobuf.message.Message):
    """Represents a generated completion alternative, including its content and generation status."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _AlternativeStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _AlternativeStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Alternative._AlternativeStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ALTERNATIVE_STATUS_UNSPECIFIED: Alternative._AlternativeStatus.ValueType  # 0
        """Unspecified generation status."""
        ALTERNATIVE_STATUS_PARTIAL: Alternative._AlternativeStatus.ValueType  # 1
        """Partially generated alternative."""
        ALTERNATIVE_STATUS_TRUNCATED_FINAL: Alternative._AlternativeStatus.ValueType  # 2
        """Incomplete final alternative resulting from reaching the maximum allowed number of tokens."""
        ALTERNATIVE_STATUS_FINAL: Alternative._AlternativeStatus.ValueType  # 3
        """Final alternative generated without running into any limits."""
        ALTERNATIVE_STATUS_CONTENT_FILTER: Alternative._AlternativeStatus.ValueType  # 4
        """Generation was stopped due to the discovery of potentially sensitive content in the prompt or generated response.
        To fix, modify the prompt and restart generation.
        """
        ALTERNATIVE_STATUS_TOOL_CALLS: Alternative._AlternativeStatus.ValueType  # 5
        """Tools were invoked during the completion generation."""

    class AlternativeStatus(_AlternativeStatus, metaclass=_AlternativeStatusEnumTypeWrapper):
        """Enum representing the generation status of the alternative."""

    ALTERNATIVE_STATUS_UNSPECIFIED: Alternative.AlternativeStatus.ValueType  # 0
    """Unspecified generation status."""
    ALTERNATIVE_STATUS_PARTIAL: Alternative.AlternativeStatus.ValueType  # 1
    """Partially generated alternative."""
    ALTERNATIVE_STATUS_TRUNCATED_FINAL: Alternative.AlternativeStatus.ValueType  # 2
    """Incomplete final alternative resulting from reaching the maximum allowed number of tokens."""
    ALTERNATIVE_STATUS_FINAL: Alternative.AlternativeStatus.ValueType  # 3
    """Final alternative generated without running into any limits."""
    ALTERNATIVE_STATUS_CONTENT_FILTER: Alternative.AlternativeStatus.ValueType  # 4
    """Generation was stopped due to the discovery of potentially sensitive content in the prompt or generated response.
    To fix, modify the prompt and restart generation.
    """
    ALTERNATIVE_STATUS_TOOL_CALLS: Alternative.AlternativeStatus.ValueType  # 5
    """Tools were invoked during the completion generation."""

    MESSAGE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    status: global___Alternative.AlternativeStatus.ValueType
    """The generation status of the alternative."""
    @property
    def message(self) -> global___Message:
        """A message with the content of the alternative."""

    def __init__(
        self,
        *,
        message: global___Message | None = ...,
        status: global___Alternative.AlternativeStatus.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["message", b"message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["message", b"message", "status", b"status"]) -> None: ...

global___Alternative = Alternative

@typing.final
class Token(google.protobuf.message.Message):
    """Represents a token, the basic unit of content, used by the foundation model."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    SPECIAL_FIELD_NUMBER: builtins.int
    id: builtins.int
    """An internal token identifier."""
    text: builtins.str
    """The textual representation of the token."""
    special: builtins.bool
    """Indicates whether the token is special or not. Special tokens may define the model's behavior and are not visible to users."""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        text: builtins.str = ...,
        special: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "special", b"special", "text", b"text"]) -> None: ...

global___Token = Token

@typing.final
class Tool(google.protobuf.message.Message):
    """Represents a tool that can be invoked during completion generation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_FIELD_NUMBER: builtins.int
    @property
    def function(self) -> global___FunctionTool:
        """Represents a function that can be called."""

    def __init__(
        self,
        *,
        function: global___FunctionTool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ToolType", b"ToolType", "function", b"function"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ToolType", b"ToolType", "function", b"function"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["ToolType", b"ToolType"]) -> typing.Literal["function"] | None: ...

global___Tool = Tool

@typing.final
class FunctionTool(google.protobuf.message.Message):
    """Represents a function tool that can be invoked during completion generation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the function."""
    description: builtins.str
    """A description of the function's purpose or behavior."""
    @property
    def parameters(self) -> google.protobuf.struct_pb2.Struct:
        """A JSON Schema that defines the expected parameters for the function.
        The schema should describe the required fields, their types, and any constraints or default values.
        """

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        parameters: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["parameters", b"parameters"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "name", b"name", "parameters", b"parameters"]) -> None: ...

global___FunctionTool = FunctionTool

@typing.final
class ToolCall(google.protobuf.message.Message):
    """Represents a call to a tool."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_CALL_FIELD_NUMBER: builtins.int
    @property
    def function_call(self) -> global___FunctionCall:
        """Represents a call to a function."""

    def __init__(
        self,
        *,
        function_call: global___FunctionCall | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ToolCallType", b"ToolCallType", "function_call", b"function_call"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ToolCallType", b"ToolCallType", "function_call", b"function_call"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["ToolCallType", b"ToolCallType"]) -> typing.Literal["function_call"] | None: ...

global___ToolCall = ToolCall

@typing.final
class FunctionCall(google.protobuf.message.Message):
    """Represents the invocation of a function with specific arguments."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ARGUMENTS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the function being called."""
    @property
    def arguments(self) -> google.protobuf.struct_pb2.Struct:
        """The structured arguments passed to the function.
        These arguments must adhere to the JSON Schema defined in the corresponding function's parameters.
        """

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        arguments: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["arguments", b"arguments"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["arguments", b"arguments", "name", b"name"]) -> None: ...

global___FunctionCall = FunctionCall

@typing.final
class ToolCallList(google.protobuf.message.Message):
    """Represents a list of tool calls."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOOL_CALLS_FIELD_NUMBER: builtins.int
    @property
    def tool_calls(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ToolCall]:
        """A list of tool calls to be executed."""

    def __init__(
        self,
        *,
        tool_calls: collections.abc.Iterable[global___ToolCall] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tool_calls", b"tool_calls"]) -> None: ...

global___ToolCallList = ToolCallList

@typing.final
class ToolResult(google.protobuf.message.Message):
    """Represents the result of a tool call."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_RESULT_FIELD_NUMBER: builtins.int
    @property
    def function_result(self) -> global___FunctionResult:
        """Represents the result of a function call."""

    def __init__(
        self,
        *,
        function_result: global___FunctionResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ToolResultType", b"ToolResultType", "function_result", b"function_result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ToolResultType", b"ToolResultType", "function_result", b"function_result"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["ToolResultType", b"ToolResultType"]) -> typing.Literal["function_result"] | None: ...

global___ToolResult = ToolResult

@typing.final
class FunctionResult(google.protobuf.message.Message):
    """Represents the result of a function call."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the function that was executed."""
    content: builtins.str
    """The result of the function call, represented as a string.
    This field can be used to store the output of the function.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        content: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ContentType", b"ContentType", "content", b"content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ContentType", b"ContentType", "content", b"content", "name", b"name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["ContentType", b"ContentType"]) -> typing.Literal["content"] | None: ...

global___FunctionResult = FunctionResult

@typing.final
class ToolResultList(google.protobuf.message.Message):
    """Represents a list of tool results."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOOL_RESULTS_FIELD_NUMBER: builtins.int
    @property
    def tool_results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ToolResult]:
        """A list of tool results."""

    def __init__(
        self,
        *,
        tool_results: collections.abc.Iterable[global___ToolResult] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tool_results", b"tool_results"]) -> None: ...

global___ToolResultList = ToolResultList



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.k8s.marketplace.v1 import helm_release_pb2 as yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__pb2
from yandex.cloud.k8s.marketplace.v1 import helm_release_service_pb2 as yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class HelmReleaseServiceStub(object):
    """A set of methods for managing Helm release.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.List = channel.unary_unary(
                '/yandex.cloud.k8s.marketplace.v1.HelmReleaseService/List',
                request_serializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.ListHelmReleasesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.ListHelmReleasesResponse.FromString,
                )
        self.Get = channel.unary_unary(
                '/yandex.cloud.k8s.marketplace.v1.HelmReleaseService/Get',
                request_serializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.GetHelmReleaseRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__pb2.HelmRelease.FromString,
                )
        self.Install = channel.unary_unary(
                '/yandex.cloud.k8s.marketplace.v1.HelmReleaseService/Install',
                request_serializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.InstallHelmReleaseRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.k8s.marketplace.v1.HelmReleaseService/Update',
                request_serializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.UpdateHelmReleaseRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Uninstall = channel.unary_unary(
                '/yandex.cloud.k8s.marketplace.v1.HelmReleaseService/Uninstall',
                request_serializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.UninstallHelmReleaseRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class HelmReleaseServiceServicer(object):
    """A set of methods for managing Helm release.
    """

    def List(self, request, context):
        """Retrieves the list of Helm releases in the specified Kubernetes Cluster.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Returns the specified Helm release.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Install(self, request, context):
        """Installs helm release into specified Kubernetes Cluster.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates helm release.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Uninstall(self, request, context):
        """Uninstalls helm release.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_HelmReleaseServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.ListHelmReleasesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.ListHelmReleasesResponse.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.GetHelmReleaseRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__pb2.HelmRelease.SerializeToString,
            ),
            'Install': grpc.unary_unary_rpc_method_handler(
                    servicer.Install,
                    request_deserializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.InstallHelmReleaseRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.UpdateHelmReleaseRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Uninstall': grpc.unary_unary_rpc_method_handler(
                    servicer.Uninstall,
                    request_deserializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.UninstallHelmReleaseRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.k8s.marketplace.v1.HelmReleaseService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class HelmReleaseService(object):
    """A set of methods for managing Helm release.
    """

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.k8s.marketplace.v1.HelmReleaseService/List',
            yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.ListHelmReleasesRequest.SerializeToString,
            yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.ListHelmReleasesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.k8s.marketplace.v1.HelmReleaseService/Get',
            yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.GetHelmReleaseRequest.SerializeToString,
            yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__pb2.HelmRelease.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Install(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.k8s.marketplace.v1.HelmReleaseService/Install',
            yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.InstallHelmReleaseRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.k8s.marketplace.v1.HelmReleaseService/Update',
            yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.UpdateHelmReleaseRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Uninstall(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.k8s.marketplace.v1.HelmReleaseService/Uninstall',
            yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.UninstallHelmReleaseRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.mdb.kafka.v1.connector_pb2
import yandex.cloud.mdb.kafka.v1.connector_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ConnectorServiceStub:
    """A set of methods for managing Apache Kafka® connectors."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.kafka.v1.connector_service_pb2.GetConnectorRequest,
        yandex.cloud.mdb.kafka.v1.connector_pb2.Connector,
    ]
    """Returns information about an Apache Kafka® connector."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.kafka.v1.connector_service_pb2.ListConnectorsRequest,
        yandex.cloud.mdb.kafka.v1.connector_service_pb2.ListConnectorsResponse,
    ]
    """Retrieves the list of Apache Kafka® connectors in a cluster."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.kafka.v1.connector_service_pb2.CreateConnectorRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new Apache Kafka® connector in a cluster."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.kafka.v1.connector_service_pb2.UpdateConnectorRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates an Apache Kafka® connector."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.kafka.v1.connector_service_pb2.DeleteConnectorRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes an Apache Kafka® connector."""

    Resume: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.kafka.v1.connector_service_pb2.ResumeConnectorRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Resumes an Apache Kafka® connector."""

    Pause: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.kafka.v1.connector_service_pb2.PauseConnectorRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Pauses an Apache Kafka® connector."""

class ConnectorServiceAsyncStub:
    """A set of methods for managing Apache Kafka® connectors."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.kafka.v1.connector_service_pb2.GetConnectorRequest,
        yandex.cloud.mdb.kafka.v1.connector_pb2.Connector,
    ]
    """Returns information about an Apache Kafka® connector."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.kafka.v1.connector_service_pb2.ListConnectorsRequest,
        yandex.cloud.mdb.kafka.v1.connector_service_pb2.ListConnectorsResponse,
    ]
    """Retrieves the list of Apache Kafka® connectors in a cluster."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.kafka.v1.connector_service_pb2.CreateConnectorRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new Apache Kafka® connector in a cluster."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.kafka.v1.connector_service_pb2.UpdateConnectorRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates an Apache Kafka® connector."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.kafka.v1.connector_service_pb2.DeleteConnectorRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes an Apache Kafka® connector."""

    Resume: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.kafka.v1.connector_service_pb2.ResumeConnectorRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Resumes an Apache Kafka® connector."""

    Pause: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.kafka.v1.connector_service_pb2.PauseConnectorRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Pauses an Apache Kafka® connector."""

class ConnectorServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Apache Kafka® connectors."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.mdb.kafka.v1.connector_service_pb2.GetConnectorRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.kafka.v1.connector_pb2.Connector, collections.abc.Awaitable[yandex.cloud.mdb.kafka.v1.connector_pb2.Connector]]:
        """Returns information about an Apache Kafka® connector."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.mdb.kafka.v1.connector_service_pb2.ListConnectorsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.kafka.v1.connector_service_pb2.ListConnectorsResponse, collections.abc.Awaitable[yandex.cloud.mdb.kafka.v1.connector_service_pb2.ListConnectorsResponse]]:
        """Retrieves the list of Apache Kafka® connectors in a cluster."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.mdb.kafka.v1.connector_service_pb2.CreateConnectorRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a new Apache Kafka® connector in a cluster."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.mdb.kafka.v1.connector_service_pb2.UpdateConnectorRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates an Apache Kafka® connector."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.mdb.kafka.v1.connector_service_pb2.DeleteConnectorRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes an Apache Kafka® connector."""

    @abc.abstractmethod
    def Resume(
        self,
        request: yandex.cloud.mdb.kafka.v1.connector_service_pb2.ResumeConnectorRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Resumes an Apache Kafka® connector."""

    @abc.abstractmethod
    def Pause(
        self,
        request: yandex.cloud.mdb.kafka.v1.connector_service_pb2.PauseConnectorRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Pauses an Apache Kafka® connector."""

def add_ConnectorServiceServicer_to_server(servicer: ConnectorServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



from concurrent import futures
from unittest.mock import Mock, patch

import grpc
import pytest

from yandex.cloud.vpc.v1.network_service_pb2 import (
    ListNetworksRequest,
    ListNetworksResponse,
)
from yandex.cloud.vpc.v1.network_service_pb2_grpc import (
    NetworkServiceStub,
    add_NetworkServiceServicer_to_server,
)
from yandexcloud import SDK
from yandexcloud._channels import Channels

INSECURE_SERVICE_PORT = "50051"
SECURE_SERVICE_PORT = "50052"
SERVICE_ADDR = "localhost"


class VPCServiceMock:

    def __init__(self):
        self.Get = Mock()
        self.Create = Mock()
        self.Update = Mock()
        self.Delete = Mock()
        self.ListSubnets = Mock()
        self.ListSecurityGroups = Mock()
        self.ListRouteTables = Mock()
        self.ListOperations = Mock()
        self.Move = Mock()

    def List(self, _, context):
        context.set_code(grpc.StatusCode.OK)
        return ListNetworksResponse()


def grpc_server():
    service = VPCServiceMock()
    server = grpc.server(futures.ThreadPoolExecutor(max_workers=10))
    server.add_insecure_port("[::]:" + INSECURE_SERVICE_PORT)
    server.add_secure_port("[::]:" + SECURE_SERVICE_PORT, server_credentials=grpc.local_server_credentials())
    add_NetworkServiceServicer_to_server(service, server)
    server.start()
    return server


@pytest.fixture
def mock_channel():
    with patch.multiple(
        Channels,
        _get_creds=lambda self, endpoint: grpc.local_channel_credentials(),
        _get_endpoints=lambda self: {"vpc": "", "iam": ""},
    ) as channel_patch:
        yield channel_patch


@pytest.mark.parametrize(["port", "insecure"], [(SECURE_SERVICE_PORT, False), (INSECURE_SERVICE_PORT, True)])
def test_we_can_override_endpoint_for_client(port: str, insecure: bool, mock_channel):
    # given
    grpc_server()
    sdk = SDK()
    # when
    network_client = sdk.client(NetworkServiceStub, endpoint=f"localhost:{port}", insecure=insecure)
    # then
    assert isinstance(network_client.List(ListNetworksRequest(folder_id="test")), ListNetworksResponse)


@pytest.mark.parametrize(["port", "insecure"], [(SECURE_SERVICE_PORT, False), (INSECURE_SERVICE_PORT, True)])
def test_we_can_override_endpoint_using_config(port: str, insecure: bool, mock_channel):
    # given
    grpc_server()
    sdk = SDK(endpoints={"vpc": f"localhost:{port}"})
    # when
    network_client = sdk.client(NetworkServiceStub, insecure=insecure)
    # then
    assert isinstance(network_client.List(ListNetworksRequest(folder_id="test")), ListNetworksResponse)


@pytest.mark.parametrize(["port", "insecure"], [(SECURE_SERVICE_PORT, False), (INSECURE_SERVICE_PORT, True)])
def test_override_by_client_is_prior(port: str, insecure: bool, mock_channel):
    # given
    grpc_server()
    sdk = SDK(endpoints={"vpc": "nonlocal-123:12323"})
    # when
    network_client = sdk.client(NetworkServiceStub, endpoint=f"localhost:{port}", insecure=insecure)
    # then
    assert isinstance(network_client.List(ListNetworksRequest(folder_id="test")), ListNetworksResponse)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2
import yandex.cloud.datatransfer.v1.endpoint.kafka_pb2
import yandex.cloud.datatransfer.v1.endpoint.metrika_pb2
import yandex.cloud.datatransfer.v1.endpoint.mongo_pb2
import yandex.cloud.datatransfer.v1.endpoint.mysql_pb2
import yandex.cloud.datatransfer.v1.endpoint.postgres_pb2
import yandex.cloud.datatransfer.v1.endpoint.ydb_pb2
import yandex.cloud.datatransfer.v1.endpoint.yds_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Endpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    id: builtins.str
    folder_id: builtins.str
    name: builtins.str
    description: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def settings(self) -> global___EndpointSettings: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        settings: global___EndpointSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "settings", b"settings"]) -> None: ...

global___Endpoint = Endpoint

@typing.final
class EndpointSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MYSQL_SOURCE_FIELD_NUMBER: builtins.int
    POSTGRES_SOURCE_FIELD_NUMBER: builtins.int
    YDB_SOURCE_FIELD_NUMBER: builtins.int
    YDS_SOURCE_FIELD_NUMBER: builtins.int
    KAFKA_SOURCE_FIELD_NUMBER: builtins.int
    MONGO_SOURCE_FIELD_NUMBER: builtins.int
    CLICKHOUSE_SOURCE_FIELD_NUMBER: builtins.int
    MYSQL_TARGET_FIELD_NUMBER: builtins.int
    POSTGRES_TARGET_FIELD_NUMBER: builtins.int
    CLICKHOUSE_TARGET_FIELD_NUMBER: builtins.int
    YDB_TARGET_FIELD_NUMBER: builtins.int
    KAFKA_TARGET_FIELD_NUMBER: builtins.int
    MONGO_TARGET_FIELD_NUMBER: builtins.int
    METRIKA_SOURCE_FIELD_NUMBER: builtins.int
    YDS_TARGET_FIELD_NUMBER: builtins.int
    @property
    def mysql_source(self) -> yandex.cloud.datatransfer.v1.endpoint.mysql_pb2.MysqlSource: ...
    @property
    def postgres_source(self) -> yandex.cloud.datatransfer.v1.endpoint.postgres_pb2.PostgresSource: ...
    @property
    def ydb_source(self) -> yandex.cloud.datatransfer.v1.endpoint.ydb_pb2.YdbSource: ...
    @property
    def yds_source(self) -> yandex.cloud.datatransfer.v1.endpoint.yds_pb2.YDSSource: ...
    @property
    def kafka_source(self) -> yandex.cloud.datatransfer.v1.endpoint.kafka_pb2.KafkaSource: ...
    @property
    def mongo_source(self) -> yandex.cloud.datatransfer.v1.endpoint.mongo_pb2.MongoSource: ...
    @property
    def clickhouse_source(self) -> yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2.ClickhouseSource: ...
    @property
    def mysql_target(self) -> yandex.cloud.datatransfer.v1.endpoint.mysql_pb2.MysqlTarget: ...
    @property
    def postgres_target(self) -> yandex.cloud.datatransfer.v1.endpoint.postgres_pb2.PostgresTarget: ...
    @property
    def clickhouse_target(self) -> yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2.ClickhouseTarget: ...
    @property
    def ydb_target(self) -> yandex.cloud.datatransfer.v1.endpoint.ydb_pb2.YdbTarget: ...
    @property
    def kafka_target(self) -> yandex.cloud.datatransfer.v1.endpoint.kafka_pb2.KafkaTarget: ...
    @property
    def mongo_target(self) -> yandex.cloud.datatransfer.v1.endpoint.mongo_pb2.MongoTarget: ...
    @property
    def metrika_source(self) -> yandex.cloud.datatransfer.v1.endpoint.metrika_pb2.MetrikaSource: ...
    @property
    def yds_target(self) -> yandex.cloud.datatransfer.v1.endpoint.yds_pb2.YDSTarget: ...
    def __init__(
        self,
        *,
        mysql_source: yandex.cloud.datatransfer.v1.endpoint.mysql_pb2.MysqlSource | None = ...,
        postgres_source: yandex.cloud.datatransfer.v1.endpoint.postgres_pb2.PostgresSource | None = ...,
        ydb_source: yandex.cloud.datatransfer.v1.endpoint.ydb_pb2.YdbSource | None = ...,
        yds_source: yandex.cloud.datatransfer.v1.endpoint.yds_pb2.YDSSource | None = ...,
        kafka_source: yandex.cloud.datatransfer.v1.endpoint.kafka_pb2.KafkaSource | None = ...,
        mongo_source: yandex.cloud.datatransfer.v1.endpoint.mongo_pb2.MongoSource | None = ...,
        clickhouse_source: yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2.ClickhouseSource | None = ...,
        mysql_target: yandex.cloud.datatransfer.v1.endpoint.mysql_pb2.MysqlTarget | None = ...,
        postgres_target: yandex.cloud.datatransfer.v1.endpoint.postgres_pb2.PostgresTarget | None = ...,
        clickhouse_target: yandex.cloud.datatransfer.v1.endpoint.clickhouse_pb2.ClickhouseTarget | None = ...,
        ydb_target: yandex.cloud.datatransfer.v1.endpoint.ydb_pb2.YdbTarget | None = ...,
        kafka_target: yandex.cloud.datatransfer.v1.endpoint.kafka_pb2.KafkaTarget | None = ...,
        mongo_target: yandex.cloud.datatransfer.v1.endpoint.mongo_pb2.MongoTarget | None = ...,
        metrika_source: yandex.cloud.datatransfer.v1.endpoint.metrika_pb2.MetrikaSource | None = ...,
        yds_target: yandex.cloud.datatransfer.v1.endpoint.yds_pb2.YDSTarget | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["clickhouse_source", b"clickhouse_source", "clickhouse_target", b"clickhouse_target", "kafka_source", b"kafka_source", "kafka_target", b"kafka_target", "metrika_source", b"metrika_source", "mongo_source", b"mongo_source", "mongo_target", b"mongo_target", "mysql_source", b"mysql_source", "mysql_target", b"mysql_target", "postgres_source", b"postgres_source", "postgres_target", b"postgres_target", "settings", b"settings", "ydb_source", b"ydb_source", "ydb_target", b"ydb_target", "yds_source", b"yds_source", "yds_target", b"yds_target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["clickhouse_source", b"clickhouse_source", "clickhouse_target", b"clickhouse_target", "kafka_source", b"kafka_source", "kafka_target", b"kafka_target", "metrika_source", b"metrika_source", "mongo_source", b"mongo_source", "mongo_target", b"mongo_target", "mysql_source", b"mysql_source", "mysql_target", b"mysql_target", "postgres_source", b"postgres_source", "postgres_target", b"postgres_target", "settings", b"settings", "ydb_source", b"ydb_source", "ydb_target", b"ydb_target", "yds_source", b"yds_source", "yds_target", b"yds_target"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["settings", b"settings"]) -> typing.Literal["mysql_source", "postgres_source", "ydb_source", "yds_source", "kafka_source", "mongo_source", "clickhouse_source", "mysql_target", "postgres_target", "clickhouse_target", "ydb_target", "kafka_target", "mongo_target", "metrika_source", "yds_target"] | None: ...

global___EndpointSettings = EndpointSettings



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/tuning/v1/tuning_schedulers.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/ai/tuning/v1/tuning_schedulers.proto\x12\x19yandex.cloud.ai.tuning.v1\"!\n\x0fSchedulerLinear\x12\x0e\n\x06min_lr\x18\x01 \x01(\x01\"\x13\n\x11SchedulerConstant\"!\n\x0fSchedulerCosine\x12\x0e\n\x06min_lr\x18\x01 \x01(\x01\x42\x63\n\x1dyandex.cloud.api.ai.tuning.v1ZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/tuning/v1;fomob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.ai.tuning.v1ZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/tuning/v1;fomo'
  _globals['_SCHEDULERLINEAR']._serialized_start=80
  _globals['_SCHEDULERLINEAR']._serialized_end=113
  _globals['_SCHEDULERCONSTANT']._serialized_start=115
  _globals['_SCHEDULERCONSTANT']._serialized_end=134
  _globals['_SCHEDULERCOSINE']._serialized_start=136
  _globals['_SCHEDULERCOSINE']._serialized_end=169
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.datasphere.v2.jobs.jobs_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _StandardStream:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _StandardStreamEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_StandardStream.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    STANDARD_STREAM_UNSPECIFIED: _StandardStream.ValueType  # 0
    OUT: _StandardStream.ValueType  # 1
    """Stdout."""
    ERR: _StandardStream.ValueType  # 2
    """Stderr."""

class StandardStream(_StandardStream, metaclass=_StandardStreamEnumTypeWrapper): ...

STANDARD_STREAM_UNSPECIFIED: StandardStream.ValueType  # 0
OUT: StandardStream.ValueType  # 1
"""Stdout."""
ERR: StandardStream.ValueType  # 2
"""Stderr."""
global___StandardStream = StandardStream

@typing.final
class CreateProjectJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    JOB_PARAMETERS_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    DATA_TTL_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project."""
    config: builtins.str
    """Config of the job."""
    name: builtins.str
    """Name of the job."""
    desc: builtins.str
    """Description of the job."""
    @property
    def job_parameters(self) -> yandex.cloud.datasphere.v2.jobs.jobs_pb2.JobParameters:
        """Parameters of the job."""

    @property
    def data_ttl(self) -> google.protobuf.duration_pb2.Duration:
        """Job data TTL."""

    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        job_parameters: yandex.cloud.datasphere.v2.jobs.jobs_pb2.JobParameters | None = ...,
        config: builtins.str = ...,
        name: builtins.str = ...,
        desc: builtins.str = ...,
        data_ttl: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data_ttl", b"data_ttl", "job_parameters", b"job_parameters"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config", b"config", "data_ttl", b"data_ttl", "desc", b"desc", "job_parameters", b"job_parameters", "name", b"name", "project_id", b"project_id"]) -> None: ...

global___CreateProjectJobRequest = CreateProjectJobRequest

@typing.final
class CreateProjectJobMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project."""
    job_id: builtins.str
    """Job ID."""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["job_id", b"job_id", "project_id", b"project_id"]) -> None: ...

global___CreateProjectJobMetadata = CreateProjectJobMetadata

@typing.final
class CreateProjectJobResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    UPLOAD_FILES_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    """ID of the job."""
    @property
    def upload_files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.datasphere.v2.jobs.jobs_pb2.StorageFile]:
        """Files to upload with their presigned URLs for upload."""

    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
        upload_files: collections.abc.Iterable[yandex.cloud.datasphere.v2.jobs.jobs_pb2.StorageFile] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["job_id", b"job_id", "upload_files", b"upload_files"]) -> None: ...

global___CreateProjectJobResponse = CreateProjectJobResponse

@typing.final
class CloneProjectJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_JOB_ID_FIELD_NUMBER: builtins.int
    JOB_PARAMETERS_OVERRIDES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    DATA_TTL_FIELD_NUMBER: builtins.int
    source_job_id: builtins.str
    """ID of job to be cloned."""
    name: builtins.str
    """New job name."""
    desc: builtins.str
    """New job description"""
    @property
    def job_parameters_overrides(self) -> yandex.cloud.datasphere.v2.jobs.jobs_pb2.JobParameters:
        """Parameters overrides."""

    @property
    def data_ttl(self) -> google.protobuf.duration_pb2.Duration:
        """Data ttl."""

    def __init__(
        self,
        *,
        source_job_id: builtins.str = ...,
        job_parameters_overrides: yandex.cloud.datasphere.v2.jobs.jobs_pb2.JobParameters | None = ...,
        name: builtins.str = ...,
        desc: builtins.str = ...,
        data_ttl: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data_ttl", b"data_ttl", "job_parameters_overrides", b"job_parameters_overrides"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data_ttl", b"data_ttl", "desc", b"desc", "job_parameters_overrides", b"job_parameters_overrides", "name", b"name", "source_job_id", b"source_job_id"]) -> None: ...

global___CloneProjectJobRequest = CloneProjectJobRequest

@typing.final
class CloneProjectJobResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    UPLOAD_FILES_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    """Job ID."""
    @property
    def upload_files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.datasphere.v2.jobs.jobs_pb2.StorageFile]:
        """Files with presigned URLs generated by server to upload them to storage. Order is arbitrary.

        Upload files include input files, executable file (python main script or binary executable) and local modules
        in case of python.

        If file was already uploaded, there will be no element for it.
        """

    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
        upload_files: collections.abc.Iterable[yandex.cloud.datasphere.v2.jobs.jobs_pb2.StorageFile] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["job_id", b"job_id", "upload_files", b"upload_files"]) -> None: ...

global___CloneProjectJobResponse = CloneProjectJobResponse

@typing.final
class CloneProjectJobMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    job_id: builtins.str
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["job_id", b"job_id", "project_id", b"project_id"]) -> None: ...

global___CloneProjectJobMetadata = CloneProjectJobMetadata

@typing.final
class ExecuteProjectJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    """ID of the job."""
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["job_id", b"job_id"]) -> None: ...

global___ExecuteProjectJobRequest = ExecuteProjectJobRequest

@typing.final
class ExecuteProjectJobResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUT_FILES_FIELD_NUMBER: builtins.int
    OUTPUT_FILES_ERRORS_FIELD_NUMBER: builtins.int
    OUTPUT_DATASETS_FIELD_NUMBER: builtins.int
    RESULT_FIELD_NUMBER: builtins.int
    @property
    def output_files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.datasphere.v2.jobs.jobs_pb2.StorageFile]:
        """Uploaded output files with URLs."""

    @property
    def output_files_errors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.datasphere.v2.jobs.jobs_pb2.FileUploadError]:
        """Output file errors"""

    @property
    def output_datasets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.datasphere.v2.jobs.jobs_pb2.OutputDataset]:
        """Created datasets"""

    @property
    def result(self) -> yandex.cloud.datasphere.v2.jobs.jobs_pb2.JobResult:
        """Result of the job."""

    def __init__(
        self,
        *,
        output_files: collections.abc.Iterable[yandex.cloud.datasphere.v2.jobs.jobs_pb2.StorageFile] | None = ...,
        output_files_errors: collections.abc.Iterable[yandex.cloud.datasphere.v2.jobs.jobs_pb2.FileUploadError] | None = ...,
        output_datasets: collections.abc.Iterable[yandex.cloud.datasphere.v2.jobs.jobs_pb2.OutputDataset] | None = ...,
        result: yandex.cloud.datasphere.v2.jobs.jobs_pb2.JobResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["output_datasets", b"output_datasets", "output_files", b"output_files", "output_files_errors", b"output_files_errors", "result", b"result"]) -> None: ...

global___ExecuteProjectJobResponse = ExecuteProjectJobResponse

@typing.final
class ExecuteProjectJobMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    @property
    def job(self) -> yandex.cloud.datasphere.v2.jobs.jobs_pb2.Job:
        """Instance of the job."""

    @property
    def progress(self) -> yandex.cloud.datasphere.v2.jobs.jobs_pb2.JobProgress:
        """Job progress info"""

    @property
    def metadata(self) -> yandex.cloud.datasphere.v2.jobs.jobs_pb2.JobMetadata:
        """Job metadata with main job info"""

    def __init__(
        self,
        *,
        job: yandex.cloud.datasphere.v2.jobs.jobs_pb2.Job | None = ...,
        progress: yandex.cloud.datasphere.v2.jobs.jobs_pb2.JobProgress | None = ...,
        metadata: yandex.cloud.datasphere.v2.jobs.jobs_pb2.JobMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["job", b"job", "metadata", b"metadata", "progress", b"progress"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["job", b"job", "metadata", b"metadata", "progress", b"progress"]) -> None: ...

global___ExecuteProjectJobMetadata = ExecuteProjectJobMetadata

@typing.final
class CancelProjectJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    GRACEFUL_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    """ID of the job."""
    reason: builtins.str
    """Optional cancellation reason."""
    graceful: builtins.bool
    """If the job is launched with graceful shutdown support, the shutdown will be performed gracefully"""
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
        reason: builtins.str = ...,
        graceful: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["graceful", b"graceful", "job_id", b"job_id", "reason", b"reason"]) -> None: ...

global___CancelProjectJobRequest = CancelProjectJobRequest

@typing.final
class ReadProjectJobStdLogsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    """ID of the job."""
    offset: builtins.int
    """Log offset."""
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
        offset: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["job_id", b"job_id", "offset", b"offset"]) -> None: ...

global___ReadProjectJobStdLogsRequest = ReadProjectJobStdLogsRequest

@typing.final
class ReadProjectJobStdLogsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOGS_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    offset: builtins.int
    """Log offset."""
    @property
    def logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StdLog]: ...
    def __init__(
        self,
        *,
        logs: collections.abc.Iterable[global___StdLog] | None = ...,
        offset: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["logs", b"logs", "offset", b"offset"]) -> None: ...

global___ReadProjectJobStdLogsResponse = ReadProjectJobStdLogsResponse

@typing.final
class ReadProjectJobLogsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    """ID of the job."""
    offset: builtins.int
    """Log offset."""
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
        offset: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["job_id", b"job_id", "offset", b"offset"]) -> None: ...

global___ReadProjectJobLogsRequest = ReadProjectJobLogsRequest

@typing.final
class ReadProjectJobLogsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOGS_FIELD_NUMBER: builtins.int
    OFFSET_FIELD_NUMBER: builtins.int
    offset: builtins.int
    """Log offset."""
    @property
    def logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LogMessage]: ...
    def __init__(
        self,
        *,
        logs: collections.abc.Iterable[global___LogMessage] | None = ...,
        offset: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["logs", b"logs", "offset", b"offset"]) -> None: ...

global___ReadProjectJobLogsResponse = ReadProjectJobLogsResponse

@typing.final
class DownloadProjectJobFilesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    FILES_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    @property
    def files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.datasphere.v2.jobs.jobs_pb2.File]: ...
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
        files: collections.abc.Iterable[yandex.cloud.datasphere.v2.jobs.jobs_pb2.File] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["files", b"files", "job_id", b"job_id"]) -> None: ...

global___DownloadProjectJobFilesRequest = DownloadProjectJobFilesRequest

@typing.final
class DownloadProjectJobFilesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOWNLOAD_FILES_FIELD_NUMBER: builtins.int
    @property
    def download_files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.datasphere.v2.jobs.jobs_pb2.StorageFile]: ...
    def __init__(
        self,
        *,
        download_files: collections.abc.Iterable[yandex.cloud.datasphere.v2.jobs.jobs_pb2.StorageFile] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["download_files", b"download_files"]) -> None: ...

global___DownloadProjectJobFilesResponse = DownloadProjectJobFilesResponse

@typing.final
class ListProjectJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListProjectJobResponse.page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListProjectJobResponse.page_token] returned by a previous list request.
    """
    filter: builtins.str
    """restrictions:
      * only `status` field is supported
      * only `IN` operator is supported
    example:
      * only running jobs == "status IN (EXECUTING, UPLOADING_OUTPUT)"
    """
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "project_id", b"project_id"]) -> None: ...

global___ListProjectJobRequest = ListProjectJobRequest

@typing.final
class ListProjectJobResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOBS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListProjectJobRequest.page_size], use
    the [next_page_token] as the value
    for the [ListProjectJobRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [page_token] to continue paging through the results.
    """
    @property
    def jobs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.datasphere.v2.jobs.jobs_pb2.Job]:
        """Instances of the jobs."""

    def __init__(
        self,
        *,
        jobs: collections.abc.Iterable[yandex.cloud.datasphere.v2.jobs.jobs_pb2.Job] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["jobs", b"jobs", "next_page_token", b"next_page_token"]) -> None: ...

global___ListProjectJobResponse = ListProjectJobResponse

@typing.final
class GetProjectJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    """ID of the job."""
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["job_id", b"job_id"]) -> None: ...

global___GetProjectJobRequest = GetProjectJobRequest

@typing.final
class DeleteProjectJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    """ID of the job."""
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["job_id", b"job_id"]) -> None: ...

global___DeleteProjectJobRequest = DeleteProjectJobRequest

@typing.final
class DeleteProjectJobMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    """ID of the job."""
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["job_id", b"job_id"]) -> None: ...

global___DeleteProjectJobMetadata = DeleteProjectJobMetadata

@typing.final
class DeleteProjectJobDataRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    """ID of the job."""
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["job_id", b"job_id"]) -> None: ...

global___DeleteProjectJobDataRequest = DeleteProjectJobDataRequest

@typing.final
class DeleteProjectJobDataMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    """ID of the job."""
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["job_id", b"job_id"]) -> None: ...

global___DeleteProjectJobDataMetadata = DeleteProjectJobDataMetadata

@typing.final
class DeleteProjectJobDataResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteProjectJobDataResponse = DeleteProjectJobDataResponse

@typing.final
class DeleteAllProjectJobDataRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___DeleteAllProjectJobDataRequest = DeleteAllProjectJobDataRequest

@typing.final
class DeleteAllProjectJobDataMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___DeleteAllProjectJobDataMetadata = DeleteAllProjectJobDataMetadata

@typing.final
class DeleteAllProjectJobDataResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteAllProjectJobDataResponse = DeleteAllProjectJobDataResponse

@typing.final
class SetProjectJobDataTtlRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    @property
    def ttl(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
        ttl: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ttl", b"ttl"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["job_id", b"job_id", "ttl", b"ttl"]) -> None: ...

global___SetProjectJobDataTtlRequest = SetProjectJobDataTtlRequest

@typing.final
class SetProjectJobDataTtlResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SetProjectJobDataTtlResponse = SetProjectJobDataTtlResponse

@typing.final
class StdLog(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[StdLog._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: StdLog._Type.ValueType  # 0
        OUT: StdLog._Type.ValueType  # 1
        """stdout."""
        ERR: StdLog._Type.ValueType  # 2
        """stderr."""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: StdLog.Type.ValueType  # 0
    OUT: StdLog.Type.ValueType  # 1
    """stdout."""
    ERR: StdLog.Type.ValueType  # 2
    """stderr."""

    CONTENT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    content: builtins.bytes
    """Log contents."""
    type: global___StdLog.Type.ValueType
    """Log type."""
    def __init__(
        self,
        *,
        content: builtins.bytes = ...,
        type: global___StdLog.Type.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["content", b"content", "type", b"type"]) -> None: ...

global___StdLog = StdLog

@typing.final
class LogMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    STANDARD_STREAM_FIELD_NUMBER: builtins.int
    FILE_PATH_FIELD_NUMBER: builtins.int
    content: builtins.bytes
    """Log message contents."""
    standard_stream: global___StandardStream.ValueType
    """Program standard streams."""
    file_path: builtins.str
    """System debug log files."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Log message creation timestamp."""

    def __init__(
        self,
        *,
        content: builtins.bytes = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        standard_stream: global___StandardStream.ValueType = ...,
        file_path: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "file_path", b"file_path", "source", b"source", "standard_stream", b"standard_stream"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["content", b"content", "created_at", b"created_at", "file_path", b"file_path", "source", b"source", "standard_stream", b"standard_stream"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["source", b"source"]) -> typing.Literal["standard_stream", "file_path"] | None: ...

global___LogMessage = LogMessage



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/cic/v1/public_connection_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.cic.v1 import public_connection_pb2 as yandex_dot_cloud_dot_cic_dot_v1_dot_public__connection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/cic/v1/public_connection_service.proto\x12\x13yandex.cloud.cic.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\x1a+yandex/cloud/cic/v1/public_connection.proto\"H\n\x1aGetPublicConnectionRequest\x12*\n\x14public_connection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x99\x01\n\x1cListPublicConnectionsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"{\n\x1dListPublicConnectionsResponse\x12\x41\n\x12public_connections\x18\x01 \x03(\x0b\x32%.yandex.cloud.cic.v1.PublicConnection\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xc6\x02\n\x17PublicConnectionService\x12\x97\x01\n\x03Get\x12/.yandex.cloud.cic.v1.GetPublicConnectionRequest\x1a%.yandex.cloud.cic.v1.PublicConnection\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/cic/v1/publicConnections/{public_connection_id}\x12\x90\x01\n\x04List\x12\x31.yandex.cloud.cic.v1.ListPublicConnectionsRequest\x1a\x32.yandex.cloud.cic.v1.ListPublicConnectionsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/cic/v1/publicConnectionsBV\n\x17yandex.cloud.api.cic.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1;cicb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cic.v1.public_connection_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.cic.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1;cic'
  _GETPUBLICCONNECTIONREQUEST.fields_by_name['public_connection_id']._options = None
  _GETPUBLICCONNECTIONREQUEST.fields_by_name['public_connection_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTPUBLICCONNECTIONSREQUEST.fields_by_name['folder_id']._options = None
  _LISTPUBLICCONNECTIONSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTPUBLICCONNECTIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTPUBLICCONNECTIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTPUBLICCONNECTIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTPUBLICCONNECTIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTPUBLICCONNECTIONSREQUEST.fields_by_name['filter']._options = None
  _LISTPUBLICCONNECTIONSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _PUBLICCONNECTIONSERVICE.methods_by_name['Get']._options = None
  _PUBLICCONNECTIONSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\0022\0220/cic/v1/publicConnections/{public_connection_id}'
  _PUBLICCONNECTIONSERVICE.methods_by_name['List']._options = None
  _PUBLICCONNECTIONSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\033\022\031/cic/v1/publicConnections'
  _globals['_GETPUBLICCONNECTIONREQUEST']._serialized_start=182
  _globals['_GETPUBLICCONNECTIONREQUEST']._serialized_end=254
  _globals['_LISTPUBLICCONNECTIONSREQUEST']._serialized_start=257
  _globals['_LISTPUBLICCONNECTIONSREQUEST']._serialized_end=410
  _globals['_LISTPUBLICCONNECTIONSRESPONSE']._serialized_start=412
  _globals['_LISTPUBLICCONNECTIONSRESPONSE']._serialized_end=535
  _globals['_PUBLICCONNECTIONSERVICE']._serialized_start=538
  _globals['_PUBLICCONNECTIONSERVICE']._serialized_end=864
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/video/v1/stream_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.video.v1 import stream_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_stream__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/video/v1/stream_service.proto\x12\x15yandex.cloud.video.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\"yandex/cloud/video/v1/stream.proto\"3\n\x10GetStreamRequest\x12\x1f\n\tstream_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xa8\x01\n\x12ListStreamsRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x64 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x65 \x01(\tB\t\x8a\xc8\x31\x05<=200\x12\x10\n\x08order_by\x18\x66 \x01(\t\x12\x1a\n\x06\x66ilter\x18g \x01(\tB\n\x8a\xc8\x31\x06<=1000J\x04\x08\x02\x10\x64\"d\n\x13ListStreamsResponse\x12.\n\x07streams\x18\x01 \x03(\x0b\x32\x1d.yandex.cloud.video.v1.Stream\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\"`\n\x16\x42\x61tchGetStreamsRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12$\n\nstream_ids\x18\x02 \x03(\tB\x10\x82\xc8\x31\x04\x31-50\x8a\xc8\x31\x04<=50\"I\n\x17\x42\x61tchGetStreamsResponse\x12.\n\x07streams\x18\x01 \x03(\x0b\x32\x1d.yandex.cloud.video.v1.Stream\"\xf7\x03\n\x13\x43reateStreamRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\x07line_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x13\n\x05title\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x1e\n\x0cthumbnail_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x88\x01\n\x06labels\x18\xc8\x01 \x03(\x0b\x32\x36.yandex.cloud.video.v1.CreateStreamRequest.LabelsEntryB?\xf2\xc7\x31\x0f[-_.@:/0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12;\n\ton_demand\x18\xe8\x07 \x01(\x0b\x32%.yandex.cloud.video.v1.OnDemandParamsH\x00\x12:\n\x08schedule\x18\xe9\x07 \x01(\x0b\x32%.yandex.cloud.video.v1.ScheduleParamsH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x13\n\x0bstream_type\x12\x04\xc0\xc1\x31\x01J\x05\x08\x06\x10\xc8\x01J\x06\x08\xc9\x01\x10\xe8\x07\"\x10\n\x0eOnDemandParams\"}\n\x0eScheduleParams\x12\x34\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x35\n\x0b\x66inish_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\")\n\x14\x43reateStreamMetadata\x12\x11\n\tstream_id\x18\x01 \x01(\t\"\x96\x04\n\x13UpdateStreamRequest\x12\x1f\n\tstream_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x19\n\x07line_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\r\n\x05title\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x1e\n\x0cthumbnail_id\x18\x06 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x88\x01\n\x06labels\x18\xc8\x01 \x03(\x0b\x32\x36.yandex.cloud.video.v1.UpdateStreamRequest.LabelsEntryB?\xf2\xc7\x31\x0f[-_.@:/0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12;\n\ton_demand\x18\xe8\x07 \x01(\x0b\x32%.yandex.cloud.video.v1.OnDemandParamsH\x00\x12:\n\x08schedule\x18\xe9\x07 \x01(\x0b\x32%.yandex.cloud.video.v1.ScheduleParamsH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\r\n\x0bstream_typeJ\x05\x08\x07\x10\xc8\x01J\x06\x08\xc9\x01\x10\xe8\x07\")\n\x14UpdateStreamMetadata\x12\x11\n\tstream_id\x18\x01 \x01(\t\"6\n\x13\x44\x65leteStreamRequest\x12\x1f\n\tstream_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x14\x44\x65leteStreamMetadata\x12\x11\n\tstream_id\x18\x01 \x01(\t\"c\n\x19\x42\x61tchDeleteStreamsRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12$\n\nstream_ids\x18\x02 \x03(\tB\x10\x82\xc8\x31\x04\x31-50\x8a\xc8\x31\x04<=50\"0\n\x1a\x42\x61tchDeleteStreamsMetadata\x12\x12\n\nstream_ids\x18\x01 \x03(\t\"\xca\x01\n\x1aPerformStreamActionRequest\x12\x1f\n\tstream_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x38\n\x07publish\x18\xe8\x07 \x01(\x0b\x32$.yandex.cloud.video.v1.PublishActionH\x00\x12\x32\n\x04stop\x18\xea\x07 \x01(\x0b\x32!.yandex.cloud.video.v1.StopActionH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01J\x06\x08\xe9\x07\x10\xea\x07J\x05\x08\x02\x10\xe8\x07\"\x0f\n\rPublishAction\"\x0c\n\nStopAction\"0\n\x1bPerformStreamActionMetadata\x12\x11\n\tstream_id\x18\x01 \x01(\t2\x93\n\n\rStreamService\x12t\n\x03Get\x12\'.yandex.cloud.video.v1.GetStreamRequest\x1a\x1d.yandex.cloud.video.v1.Stream\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/video/v1/streams/{stream_id}\x12x\n\x04List\x12).yandex.cloud.video.v1.ListStreamsRequest\x1a*.yandex.cloud.video.v1.ListStreamsResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/video/v1/streams\x12\x90\x01\n\x08\x42\x61tchGet\x12-.yandex.cloud.video.v1.BatchGetStreamsRequest\x1a..yandex.cloud.video.v1.BatchGetStreamsResponse\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/video/v1/streams:batchGet:\x01*\x12\x97\x01\n\x06\x43reate\x12*.yandex.cloud.video.v1.CreateStreamRequest\x1a!.yandex.cloud.operation.Operation\">\xb2\xd2*\x1e\n\x14\x43reateStreamMetadata\x12\x06Stream\x82\xd3\xe4\x93\x02\x16\"\x11/video/v1/streams:\x01*\x12\xa3\x01\n\x06Update\x12*.yandex.cloud.video.v1.UpdateStreamRequest\x1a!.yandex.cloud.operation.Operation\"J\xb2\xd2*\x1e\n\x14UpdateStreamMetadata\x12\x06Stream\x82\xd3\xe4\x93\x02\"2\x1d/video/v1/streams/{stream_id}:\x01*\x12\xaf\x01\n\x06\x44\x65lete\x12*.yandex.cloud.video.v1.DeleteStreamRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2*-\n\x14\x44\x65leteStreamMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1f*\x1d/video/v1/streams/{stream_id}\x12\xc3\x01\n\x0b\x42\x61tchDelete\x12\x30.yandex.cloud.video.v1.BatchDeleteStreamsRequest\x1a!.yandex.cloud.operation.Operation\"_\xb2\xd2*3\n\x1a\x42\x61tchDeleteStreamsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\"\"\x1d/video/v1/streams:batchDelete:\x01*\x12\xc6\x01\n\rPerformAction\x12\x31.yandex.cloud.video.v1.PerformStreamActionRequest\x1a!.yandex.cloud.operation.Operation\"_\xb2\xd2*%\n\x1bPerformStreamActionMetadata\x12\x06Stream\x82\xd3\xe4\x93\x02\x30\"+/video/v1/streams/{stream_id}:performAction:\x01*B\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.stream_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _GETSTREAMREQUEST.fields_by_name['stream_id']._options = None
  _GETSTREAMREQUEST.fields_by_name['stream_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSTREAMSREQUEST.fields_by_name['channel_id']._options = None
  _LISTSTREAMSREQUEST.fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSTREAMSREQUEST.fields_by_name['page_size']._options = None
  _LISTSTREAMSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTSTREAMSREQUEST.fields_by_name['page_token']._options = None
  _LISTSTREAMSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=200'
  _LISTSTREAMSREQUEST.fields_by_name['filter']._options = None
  _LISTSTREAMSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _BATCHGETSTREAMSREQUEST.fields_by_name['channel_id']._options = None
  _BATCHGETSTREAMSREQUEST.fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _BATCHGETSTREAMSREQUEST.fields_by_name['stream_ids']._options = None
  _BATCHGETSTREAMSREQUEST.fields_by_name['stream_ids']._serialized_options = b'\202\3101\0041-50\212\3101\004<=50'
  _CREATESTREAMREQUEST_LABELSENTRY._options = None
  _CREATESTREAMREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATESTREAMREQUEST.oneofs_by_name['stream_type']._options = None
  _CREATESTREAMREQUEST.oneofs_by_name['stream_type']._serialized_options = b'\300\3011\001'
  _CREATESTREAMREQUEST.fields_by_name['channel_id']._options = None
  _CREATESTREAMREQUEST.fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATESTREAMREQUEST.fields_by_name['line_id']._options = None
  _CREATESTREAMREQUEST.fields_by_name['line_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATESTREAMREQUEST.fields_by_name['title']._options = None
  _CREATESTREAMREQUEST.fields_by_name['title']._serialized_options = b'\350\3071\001'
  _CREATESTREAMREQUEST.fields_by_name['thumbnail_id']._options = None
  _CREATESTREAMREQUEST.fields_by_name['thumbnail_id']._serialized_options = b'\212\3101\004<=50'
  _CREATESTREAMREQUEST.fields_by_name['labels']._options = None
  _CREATESTREAMREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_.@:/0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _SCHEDULEPARAMS.fields_by_name['start_time']._options = None
  _SCHEDULEPARAMS.fields_by_name['start_time']._serialized_options = b'\350\3071\001'
  _SCHEDULEPARAMS.fields_by_name['finish_time']._options = None
  _SCHEDULEPARAMS.fields_by_name['finish_time']._serialized_options = b'\350\3071\001'
  _UPDATESTREAMREQUEST_LABELSENTRY._options = None
  _UPDATESTREAMREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATESTREAMREQUEST.fields_by_name['stream_id']._options = None
  _UPDATESTREAMREQUEST.fields_by_name['stream_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATESTREAMREQUEST.fields_by_name['line_id']._options = None
  _UPDATESTREAMREQUEST.fields_by_name['line_id']._serialized_options = b'\212\3101\004<=50'
  _UPDATESTREAMREQUEST.fields_by_name['thumbnail_id']._options = None
  _UPDATESTREAMREQUEST.fields_by_name['thumbnail_id']._serialized_options = b'\212\3101\004<=50'
  _UPDATESTREAMREQUEST.fields_by_name['labels']._options = None
  _UPDATESTREAMREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_.@:/0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _DELETESTREAMREQUEST.fields_by_name['stream_id']._options = None
  _DELETESTREAMREQUEST.fields_by_name['stream_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _BATCHDELETESTREAMSREQUEST.fields_by_name['channel_id']._options = None
  _BATCHDELETESTREAMSREQUEST.fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _BATCHDELETESTREAMSREQUEST.fields_by_name['stream_ids']._options = None
  _BATCHDELETESTREAMSREQUEST.fields_by_name['stream_ids']._serialized_options = b'\202\3101\0041-50\212\3101\004<=50'
  _PERFORMSTREAMACTIONREQUEST.oneofs_by_name['action']._options = None
  _PERFORMSTREAMACTIONREQUEST.oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _PERFORMSTREAMACTIONREQUEST.fields_by_name['stream_id']._options = None
  _PERFORMSTREAMACTIONREQUEST.fields_by_name['stream_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STREAMSERVICE.methods_by_name['Get']._options = None
  _STREAMSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\037\022\035/video/v1/streams/{stream_id}'
  _STREAMSERVICE.methods_by_name['List']._options = None
  _STREAMSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\023\022\021/video/v1/streams'
  _STREAMSERVICE.methods_by_name['BatchGet']._options = None
  _STREAMSERVICE.methods_by_name['BatchGet']._serialized_options = b'\202\323\344\223\002\037\"\032/video/v1/streams:batchGet:\001*'
  _STREAMSERVICE.methods_by_name['Create']._options = None
  _STREAMSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\036\n\024CreateStreamMetadata\022\006Stream\202\323\344\223\002\026\"\021/video/v1/streams:\001*'
  _STREAMSERVICE.methods_by_name['Update']._options = None
  _STREAMSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\036\n\024UpdateStreamMetadata\022\006Stream\202\323\344\223\002\"2\035/video/v1/streams/{stream_id}:\001*'
  _STREAMSERVICE.methods_by_name['Delete']._options = None
  _STREAMSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*-\n\024DeleteStreamMetadata\022\025google.protobuf.Empty\202\323\344\223\002\037*\035/video/v1/streams/{stream_id}'
  _STREAMSERVICE.methods_by_name['BatchDelete']._options = None
  _STREAMSERVICE.methods_by_name['BatchDelete']._serialized_options = b'\262\322*3\n\032BatchDeleteStreamsMetadata\022\025google.protobuf.Empty\202\323\344\223\002\"\"\035/video/v1/streams:batchDelete:\001*'
  _STREAMSERVICE.methods_by_name['PerformAction']._options = None
  _STREAMSERVICE.methods_by_name['PerformAction']._serialized_options = b'\262\322*%\n\033PerformStreamActionMetadata\022\006Stream\202\323\344\223\0020\"+/video/v1/streams/{stream_id}:performAction:\001*'
  _globals['_GETSTREAMREQUEST']._serialized_start=307
  _globals['_GETSTREAMREQUEST']._serialized_end=358
  _globals['_LISTSTREAMSREQUEST']._serialized_start=361
  _globals['_LISTSTREAMSREQUEST']._serialized_end=529
  _globals['_LISTSTREAMSRESPONSE']._serialized_start=531
  _globals['_LISTSTREAMSRESPONSE']._serialized_end=631
  _globals['_BATCHGETSTREAMSREQUEST']._serialized_start=633
  _globals['_BATCHGETSTREAMSREQUEST']._serialized_end=729
  _globals['_BATCHGETSTREAMSRESPONSE']._serialized_start=731
  _globals['_BATCHGETSTREAMSRESPONSE']._serialized_end=804
  _globals['_CREATESTREAMREQUEST']._serialized_start=807
  _globals['_CREATESTREAMREQUEST']._serialized_end=1310
  _globals['_CREATESTREAMREQUEST_LABELSENTRY']._serialized_start=1229
  _globals['_CREATESTREAMREQUEST_LABELSENTRY']._serialized_end=1274
  _globals['_ONDEMANDPARAMS']._serialized_start=1312
  _globals['_ONDEMANDPARAMS']._serialized_end=1328
  _globals['_SCHEDULEPARAMS']._serialized_start=1330
  _globals['_SCHEDULEPARAMS']._serialized_end=1455
  _globals['_CREATESTREAMMETADATA']._serialized_start=1457
  _globals['_CREATESTREAMMETADATA']._serialized_end=1498
  _globals['_UPDATESTREAMREQUEST']._serialized_start=1501
  _globals['_UPDATESTREAMREQUEST']._serialized_end=2035
  _globals['_UPDATESTREAMREQUEST_LABELSENTRY']._serialized_start=1229
  _globals['_UPDATESTREAMREQUEST_LABELSENTRY']._serialized_end=1274
  _globals['_UPDATESTREAMMETADATA']._serialized_start=2037
  _globals['_UPDATESTREAMMETADATA']._serialized_end=2078
  _globals['_DELETESTREAMREQUEST']._serialized_start=2080
  _globals['_DELETESTREAMREQUEST']._serialized_end=2134
  _globals['_DELETESTREAMMETADATA']._serialized_start=2136
  _globals['_DELETESTREAMMETADATA']._serialized_end=2177
  _globals['_BATCHDELETESTREAMSREQUEST']._serialized_start=2179
  _globals['_BATCHDELETESTREAMSREQUEST']._serialized_end=2278
  _globals['_BATCHDELETESTREAMSMETADATA']._serialized_start=2280
  _globals['_BATCHDELETESTREAMSMETADATA']._serialized_end=2328
  _globals['_PERFORMSTREAMACTIONREQUEST']._serialized_start=2331
  _globals['_PERFORMSTREAMACTIONREQUEST']._serialized_end=2533
  _globals['_PUBLISHACTION']._serialized_start=2535
  _globals['_PUBLISHACTION']._serialized_end=2550
  _globals['_STOPACTION']._serialized_start=2552
  _globals['_STOPACTION']._serialized_end=2564
  _globals['_PERFORMSTREAMACTIONMETADATA']._serialized_start=2566
  _globals['_PERFORMSTREAMACTIONMETADATA']._serialized_end=2614
  _globals['_STREAMSERVICE']._serialized_start=2617
  _globals['_STREAMSERVICE']._serialized_end=3916
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.backup.v1.provider_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ProviderServiceStub:
    """A set of methods for managing [backup providers](/docs/backup/concepts/#providers)."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Activate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.provider_service_pb2.ActivateProviderRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Activate provider for specified client."""

    ListActivated: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.provider_service_pb2.ListActivatedProvidersRequest,
        yandex.cloud.backup.v1.provider_service_pb2.ListActivatedProvidersResponse,
    ]
    """List activated providers for specified client."""

class ProviderServiceAsyncStub:
    """A set of methods for managing [backup providers](/docs/backup/concepts/#providers)."""

    Activate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.provider_service_pb2.ActivateProviderRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Activate provider for specified client."""

    ListActivated: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.provider_service_pb2.ListActivatedProvidersRequest,
        yandex.cloud.backup.v1.provider_service_pb2.ListActivatedProvidersResponse,
    ]
    """List activated providers for specified client."""

class ProviderServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing [backup providers](/docs/backup/concepts/#providers)."""

    @abc.abstractmethod
    def Activate(
        self,
        request: yandex.cloud.backup.v1.provider_service_pb2.ActivateProviderRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Activate provider for specified client."""

    @abc.abstractmethod
    def ListActivated(
        self,
        request: yandex.cloud.backup.v1.provider_service_pb2.ListActivatedProvidersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.backup.v1.provider_service_pb2.ListActivatedProvidersResponse, collections.abc.Awaitable[yandex.cloud.backup.v1.provider_service_pb2.ListActivatedProvidersResponse]]:
        """List activated providers for specified client."""

def add_ProviderServiceServicer_to_server(servicer: ProviderServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.ai.assistants.v1.searchindex.common_pb2
import yandex.cloud.ai.common.common_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SearchIndex(google.protobuf.message.Message):
    """Represents a search index used to store and query data, either using traditional keyword-based text search or vector-based search mechanisms."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_BY_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    EXPIRATION_CONFIG_FIELD_NUMBER: builtins.int
    EXPIRES_AT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TEXT_SEARCH_INDEX_FIELD_NUMBER: builtins.int
    VECTOR_SEARCH_INDEX_FIELD_NUMBER: builtins.int
    HYBRID_SEARCH_INDEX_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the search index."""
    folder_id: builtins.str
    """ID of the folder that the search index belongs to."""
    name: builtins.str
    """Name of the search index."""
    description: builtins.str
    """Description of the search index."""
    created_by: builtins.str
    """Identifier of the subject who created this search index."""
    updated_by: builtins.str
    """Identifier of the subject who last updated this search index."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp representing when the search index was created."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp representing the last time this search index was updated."""

    @property
    def expiration_config(self) -> yandex.cloud.ai.common.common_pb2.ExpirationConfig:
        """Configuration for the expiration of the search index, defining when and how the search index will expire."""

    @property
    def expires_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp representing when the search index will expire."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Set of key-value pairs that can be used to organize and categorize the search index."""

    @property
    def text_search_index(self) -> global___TextSearchIndex:
        """Keyword-based text search index configuration.
        This type of index is used for traditional text search, where documents are indexed based on their keywords.
        """

    @property
    def vector_search_index(self) -> global___VectorSearchIndex:
        """Vector-based search index configuration.
        This type is used for vector search, where documents are indexed using vector embeddings.
        """

    @property
    def hybrid_search_index(self) -> global___HybridSearchIndex:
        """Hybrid (vector-based + keyword-based) search index configuration
        This type is used for hybrid search, where documents are indexed using both keyword-based and vector-based search mechanisms.
        """

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        created_by: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_by: builtins.str = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        expiration_config: yandex.cloud.ai.common.common_pb2.ExpirationConfig | None = ...,
        expires_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        text_search_index: global___TextSearchIndex | None = ...,
        vector_search_index: global___VectorSearchIndex | None = ...,
        hybrid_search_index: global___HybridSearchIndex | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["IndexType", b"IndexType", "created_at", b"created_at", "expiration_config", b"expiration_config", "expires_at", b"expires_at", "hybrid_search_index", b"hybrid_search_index", "text_search_index", b"text_search_index", "updated_at", b"updated_at", "vector_search_index", b"vector_search_index"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["IndexType", b"IndexType", "created_at", b"created_at", "created_by", b"created_by", "description", b"description", "expiration_config", b"expiration_config", "expires_at", b"expires_at", "folder_id", b"folder_id", "hybrid_search_index", b"hybrid_search_index", "id", b"id", "labels", b"labels", "name", b"name", "text_search_index", b"text_search_index", "updated_at", b"updated_at", "updated_by", b"updated_by", "vector_search_index", b"vector_search_index"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["IndexType", b"IndexType"]) -> typing.Literal["text_search_index", "vector_search_index", "hybrid_search_index"] | None: ...

global___SearchIndex = SearchIndex

@typing.final
class TextSearchIndex(google.protobuf.message.Message):
    """Defines the configuration for a traditional keyword-based text search index."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHUNKING_STRATEGY_FIELD_NUMBER: builtins.int
    @property
    def chunking_strategy(self) -> yandex.cloud.ai.assistants.v1.searchindex.common_pb2.ChunkingStrategy:
        """Chunking strategy used to split text into smaller chunks before indexing.
        In the case of text search, tokens are individual text characters.
        """

    def __init__(
        self,
        *,
        chunking_strategy: yandex.cloud.ai.assistants.v1.searchindex.common_pb2.ChunkingStrategy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["chunking_strategy", b"chunking_strategy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["chunking_strategy", b"chunking_strategy"]) -> None: ...

global___TextSearchIndex = TextSearchIndex

@typing.final
class VectorSearchIndex(google.protobuf.message.Message):
    """Defines the configuration for a vector-based search index. This type uses embeddings to represent documents and queries."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOC_EMBEDDER_URI_FIELD_NUMBER: builtins.int
    QUERY_EMBEDDER_URI_FIELD_NUMBER: builtins.int
    CHUNKING_STRATEGY_FIELD_NUMBER: builtins.int
    doc_embedder_uri: builtins.str
    """The [ID of the model](/docs/foundation-models/concepts/embeddings) to be used for obtaining document text embeddings."""
    query_embedder_uri: builtins.str
    """The [ID of the model](/docs/foundation-models/concepts/embeddings) to be used for obtaining query text embeddings."""
    @property
    def chunking_strategy(self) -> yandex.cloud.ai.assistants.v1.searchindex.common_pb2.ChunkingStrategy:
        """Chunking strategy used to split text into smaller chunks before indexing.
        In the case of vector search, tokens are produced by the tokenizer from the embedding model.
        """

    def __init__(
        self,
        *,
        doc_embedder_uri: builtins.str = ...,
        query_embedder_uri: builtins.str = ...,
        chunking_strategy: yandex.cloud.ai.assistants.v1.searchindex.common_pb2.ChunkingStrategy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["chunking_strategy", b"chunking_strategy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["chunking_strategy", b"chunking_strategy", "doc_embedder_uri", b"doc_embedder_uri", "query_embedder_uri", b"query_embedder_uri"]) -> None: ...

global___VectorSearchIndex = VectorSearchIndex

@typing.final
class HybridSearchIndex(google.protobuf.message.Message):
    """Defines the configuration for a hybrid (vector-based + keyword-based) search index. This type uses both embeddings and keyword-based search to represent documents and queries."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_SEARCH_INDEX_FIELD_NUMBER: builtins.int
    VECTOR_SEARCH_INDEX_FIELD_NUMBER: builtins.int
    CHUNKING_STRATEGY_FIELD_NUMBER: builtins.int
    NORMALIZATION_STRATEGY_FIELD_NUMBER: builtins.int
    COMBINATION_STRATEGY_FIELD_NUMBER: builtins.int
    normalization_strategy: yandex.cloud.ai.assistants.v1.searchindex.common_pb2.NormalizationStrategy.ValueType
    """Normalization strategy for relevance scores from different indices. Default is MIN_MAX_STRATEGY"""
    @property
    def text_search_index(self) -> global___TextSearchIndex:
        """Configuration for a traditional keyword-based text search index."""

    @property
    def vector_search_index(self) -> global___VectorSearchIndex:
        """Configuration for a vector-based search index."""

    @property
    def chunking_strategy(self) -> yandex.cloud.ai.assistants.v1.searchindex.common_pb2.ChunkingStrategy:
        """Common chunking strategy that applies to both text and vector search indexes.
        If provided, it overrides the individual chunking strategies in both `text_search_index` and `vector_search_index`.
        In this case, both text and vector search will use token-based chunking, where tokens are produced by the tokenizer of the embedding model.
        """

    @property
    def combination_strategy(self) -> yandex.cloud.ai.assistants.v1.searchindex.common_pb2.CombinationStrategy:
        """Combination strategy for merging rankings from different indices. Default is arithmetic mean"""

    def __init__(
        self,
        *,
        text_search_index: global___TextSearchIndex | None = ...,
        vector_search_index: global___VectorSearchIndex | None = ...,
        chunking_strategy: yandex.cloud.ai.assistants.v1.searchindex.common_pb2.ChunkingStrategy | None = ...,
        normalization_strategy: yandex.cloud.ai.assistants.v1.searchindex.common_pb2.NormalizationStrategy.ValueType = ...,
        combination_strategy: yandex.cloud.ai.assistants.v1.searchindex.common_pb2.CombinationStrategy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["chunking_strategy", b"chunking_strategy", "combination_strategy", b"combination_strategy", "text_search_index", b"text_search_index", "vector_search_index", b"vector_search_index"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["chunking_strategy", b"chunking_strategy", "combination_strategy", b"combination_strategy", "normalization_strategy", b"normalization_strategy", "text_search_index", b"text_search_index", "vector_search_index", b"vector_search_index"]) -> None: ...

global___HybridSearchIndex = HybridSearchIndex



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.marketplace.metering.v1.product_usage_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ProductUsageServiceStub:
    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Write: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.marketplace.metering.v1.product_usage_service_pb2.WriteUsageRequest,
        yandex.cloud.marketplace.metering.v1.product_usage_service_pb2.WriteUsageResponse,
    ]
    """Writes product's usage (authenticated by publisher's service account)"""

class ProductUsageServiceAsyncStub:
    Write: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.marketplace.metering.v1.product_usage_service_pb2.WriteUsageRequest,
        yandex.cloud.marketplace.metering.v1.product_usage_service_pb2.WriteUsageResponse,
    ]
    """Writes product's usage (authenticated by publisher's service account)"""

class ProductUsageServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Write(
        self,
        request: yandex.cloud.marketplace.metering.v1.product_usage_service_pb2.WriteUsageRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.marketplace.metering.v1.product_usage_service_pb2.WriteUsageResponse, collections.abc.Awaitable[yandex.cloud.marketplace.metering.v1.product_usage_service_pb2.WriteUsageResponse]]:
        """Writes product's usage (authenticated by publisher's service account)"""

def add_ProductUsageServiceServicer_to_server(servicer: ProductUsageServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
